pub enum Error {
Transport(Box<dyn Error + Send + Sync>),
Json(Error),
Rpc(RpcError),
NonceMismatch,
VersionMismatch,
EmptyBatch,
WrongBatchResponseSize,
BatchDuplicateResponseId(Value),
WrongBatchResponseId(Value),
}Expand description
A library error
Variants
Transport(Box<dyn Error + Send + Sync>)
A transport error
Json(Error)
Json error
Rpc(RpcError)
Error response
NonceMismatch
Response to a request did not have the expected nonce
VersionMismatch
Response to a request had a jsonrpc field other than “2.0”
EmptyBatch
Batches can’t be empty
WrongBatchResponseSize
Too many responses returned in batch
BatchDuplicateResponseId(Value)
Batch response contained a duplicate ID
WrongBatchResponseId(Value)
Batch response contained an ID that didn’t correspond to any request ID